% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_Weighted.R
\name{ProbsWeighted}
\alias{ProbsWeighted}
\title{Computing the weighted tercile probabilities for SFSs.}
\usage{
ProbsWeighted(var_exp, aweights, time_dim_name = "time")
}
\arguments{
\item{var_exp}{Variable (e.g. precipitation, temperature, NAO index)
array from a SFS with at least dimensions (time, member) for a zonal 
variable or dimensions (time, member, lat, lon) for a spatial 
variable, as 'time' the spatial dimension by default.}

\item{aweights}{Normalized weights array with at least dimensions 
(time, member), when 'time' is the temporal dimension as default.}

\item{time_dim_name}{A character string indicating the name of the 
temporal dimension, by default 'time'.}
}
\value{
ProbsWeighted() returns an array with at least two or four dimensions
depending if the variable is zonal (as e.g. NAO index)(time, tercil)
or it is spatial variable (as e.g. precipitation or temperature)
(time, tercile, lat, lon), containing the terciles probabilities computing
with weighted members.
The first tercil is the lower tercile, the second is the normal tercile and
the third is the upper tercile.
}
\description{
This function implements the computation to obtain the tercile
probabilities for a weighted variable for SFSs using a normalized weights array,
}
\examples{
# Example 1 
var_exp <- 1 : (2 * 4)
dim(var_exp) <- c(time = 2, member = 4)
aweights<- c(0.2, 0.1, 0.3, 0.4, 0.1, 0.2, 0.4, 0.3)
dim(aweights) <- c(time = 2, member = 4)
res <- ProbsWeighted(var_exp, aweights)
dim(res)
# time tercil 
#    2      3 
# Example 2 
var_exp <- rnorm(48, 50, 9)
dim(var_exp) <- c(time = 2, member = 4, lat = 2, lon = 3)
aweights<- c(0.2, 0.1, 0.3, 0.4, 0.1, 0.2, 0.4, 0.3)
dim(aweights) <- c(time = 2, member = 4)
res <- ProbsWeighted(var_exp, aweights)
dim(res)
# time  tercil  lat     lon
#    2       3    2       3
}
\author{
Eroteida Sanchez-Garcia - AEMET, \email{esanchezg@aemet.es}
}
\references{
Regionally improved seasonal forecast of precipitation through Best
estimation of winter NAO, Sanchez-Garcia, E. et al.,
Adv. Sci. Res., 16, 165174, 2019, https://doi.org/10.5194/asr-16-165-2019
}

